==> SeasObjects_for_Python-1.0.1.tar.gz: SeasObjects_for_Python-1.0.1/SeasObjects/model/Error.py <==
from SeasObjects.common.PROPERTY import PROPERTY
from SeasObjects.common.CLASS import CLASS
from SeasObjects.model.Obj import Obj


class Error(Obj):
	
	def __init__(self, uri = None):
		Obj.__init__(self, uri)
		self.message = None
		self.code = 0
		self.setType(CLASS.SEAS_ERROR);
	
	def setErrorMessage(self, em):
		self.message = em
	
	def getErrorMessage(self):
		return self.message
	
	def setErrorCode(self, ec):
		self.code = ec
	
	def getErrorCode(self):
		return self.code
	
	def hasErrorCode(self):
		return self.code > 0
	
	def hasErrorMessage(self):
		return self.message != None
	
	def serialize(self, model):
		error = super(Error, self).serialize(model)
		
		if self.hasErrorMessage():
			error.addProperty(model.createProperty( PROPERTY.SEAS_ERRORMESSAGE ), model.createLiteral(self.getErrorMessage()))
		
		if self.hasErrorCode():
			error.addProperty(model.createProperty( PROPERTY.SEAS_ERRORCODE ), model.createLiteral(self.getErrorCode()))
		
		return error
	
	def parse(self, resource):
		if not resource.isAnon():
			e = Error(resource.toString())
		else:
			e = Error()
		e.clearTypes()

		for statement in resource.findProperties():
			# get predicate
			predicate = str(statement.getPredicate())

			# managedby
			if predicate == PROPERTY.SEAS_ERRORMESSAGE:
				e.message = statement.getResource().toString()
				continue

			# interfaceaddress
			if predicate == PROPERTY.SEAS_ERRORCODE:
				e.code = int(statement.getResource().toString())
				continue

			# pass on to Object
			super(Error, self).parse(statement)
		
		return e

==> SeasObjects_for_Python-1.0.4.tar.gz: SeasObjects_for_Python-1.0.4/SeasObjects/model/Error.py <==
from SeasObjects.common.PROPERTY import PROPERTY
from SeasObjects.common.RESOURCE import RESOURCE
from SeasObjects.model.Obj import Obj


class Error(Obj):
	
	def __init__(self, uri = None):
		Obj.__init__(self, uri)
		self.message = None
		self.code = 0
		self.setType(RESOURCE.SEAS_ERROR);
	
	def setErrorMessage(self, em):
		self.message = em
	
	def getErrorMessage(self):
		return self.message
	
	def setErrorCode(self, ec):
		self.code = ec
	
	def getErrorCode(self):
		return self.code
	
	def hasErrorCode(self):
		return self.code > 0
	
	def hasErrorMessage(self):
		return self.message != None
	
	def serialize(self, model):
		error = super(Error, self).serialize(model)
		
		if self.hasErrorMessage():
			error.addProperty(model.createProperty( PROPERTY.SEAS_ERRORMESSAGE ), model.createLiteral(self.getErrorMessage()))
		
		if self.hasErrorCode():
			error.addProperty(model.createProperty( PROPERTY.SEAS_ERRORCODE ), model.createLiteral(self.getErrorCode()))
		
		return error
	
	def parse(self, resource):
		if not resource.isAnon():
			e = Error(resource.toString())
		else:
			e = Error()
		e.clearTypes()

		for statement in resource.findProperties():
			# get predicate
			predicate = str(statement.getPredicate())

			# managedby
			if predicate == PROPERTY.SEAS_ERRORMESSAGE:
				e.message = statement.getResource().toString()
				continue

			# interfaceaddress
			if predicate == PROPERTY.SEAS_ERRORCODE:
				e.code = int(statement.getResource().toString())
				continue

			# pass on to Object
			super(Error, self).parse(statement)
		
		return e
